==> react-native-ui-view-0.1.5.tgz: package/esm/components/TabBar/tabBar.js <==
/* eslint-disable react-native/no-inline-styles */
import React, { Children, cloneElement } from 'react';
import { StyleSheet, View } from 'react-native';
const TabBar = props => {
    const { style = {}, height = 50, iconSize = 20, activeColor = '#5098FF', inactiveColor = '#606266', showBorderTop = true, backgroundColor = '#FFFFFF', children, } = props;
    const getPanes = (showContent) => {
        let selectedIndex = 0;
        [].concat(children).forEach((child, idx) => {
            if (child.props.selected) {
                selectedIndex = idx;
            }
        });
        const newChildren = [];
        Children.map(children, (child, idx) => {
            if (showContent) {
                // newChildren.push(child.props.children);
                newChildren.push(React.createElement(View, { style: { flex: 1, display: selectedIndex === idx ? 'flex' : 'none' } }, child.props.children));
            }
            else {
                newChildren.push(cloneElement(child, {
                    key: idx,
                    activeColor,
                    inactiveColor,
                    iconSize,
                    convexBackgroundColor: backgroundColor,
                }));
            }
        });
        // if (showContent) {
        //   return newChildren.filter((_, i) => i === selectedIndex);
        // }
        return newChildren;
    };
    return (React.createElement(View, { style: [styles.page] },
        React.createElement(View, { style: [{ flex: 1, paddingBottom: height }, style] }, getPanes(true)),
        React.createElement(View, { style: [styles.tabBar, { backgroundColor, height }, showBorderTop && styles.borderTop] }, getPanes(false))));
};
const styles = StyleSheet.create({
    page: {
        flex: 1,
    },
    tabBar: {
        position: 'absolute',
        bottom: 0,
        left: 0,
        width: '100%',
        display: 'flex',
        flexDirection: 'row',
    },
    borderTop: {
        borderTopColor: '#E4E7ED',
        borderTopWidth: 1,
    },
});
export default TabBar;

==> react-native-ui-view-0.1.6.tgz: package/esm/components/TabBar/tabBar.js <==
/* eslint-disable react-native/no-inline-styles */
import React, { Children, cloneElement } from 'react';
import { StyleSheet, View } from 'react-native';
const TabBar = props => {
    const { style = {}, height = 50, iconSize = 20, activeColor = '#5098FF', inactiveColor = '#606266', showBorderTop = true, backgroundColor = '#FFFFFF', children, } = props;
    const getPanes = (showContent) => {
        let selectedIndex = 0;
        [].concat(children).forEach((child, idx) => {
            if (child.props.selected) {
                selectedIndex = idx;
            }
        });
        const newChildren = [];
        Children.map(children, (child, idx) => {
            if (showContent) {
                // newChildren.push(child.props.children);
                newChildren.push(React.createElement(View, { key: idx, style: { flex: 1, display: selectedIndex === idx ? 'flex' : 'none' } }, child.props.children));
            }
            else {
                newChildren.push(cloneElement(child, {
                    key: idx,
                    activeColor,
                    inactiveColor,
                    iconSize,
                    convexBackgroundColor: backgroundColor,
                }));
            }
        });
        // if (showContent) {
        //   return newChildren.filter((_, i) => i === selectedIndex);
        // }
        return newChildren;
    };
    return (React.createElement(View, { style: [styles.page] },
        React.createElement(View, { style: [{ flex: 1, paddingBottom: height }, style] }, getPanes(true)),
        React.createElement(View, { style: [styles.tabBar, { backgroundColor, height }, showBorderTop && styles.borderTop] }, getPanes(false))));
};
const styles = StyleSheet.create({
    page: {
        flex: 1,
    },
    tabBar: {
        position: 'absolute',
        bottom: 0,
        left: 0,
        width: '100%',
        display: 'flex',
        flexDirection: 'row',
    },
    borderTop: {
        borderTopColor: '#E4E7ED',
        borderTopWidth: 1,
    },
});
export default TabBar;
